summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexi.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/core/kexi.h')
-rw-r--r--kexi/core/kexi.h60
1 files changed, 30 insertions, 30 deletions
diff --git a/kexi/core/kexi.h b/kexi/core/kexi.h
index 8490ca290..a98f93413 100644
--- a/kexi/core/kexi.h
+++ b/kexi/core/kexi.h
@@ -20,8 +20,8 @@
#ifndef KEXI_H
#define KEXI_H
-#include <qguardedptr.h>
-#include <qfont.h>
+#include <tqguardedptr.h>
+#include <tqfont.h>
#include <kexi_version.h>
#include "kexiprojectdata.h"
@@ -42,13 +42,13 @@ namespace Kexi
enum ViewMode {
AllViewModes = 0, //!< Usable primarily in KexiPart::initInstanceActions()
NoViewMode = 0, //!< In KexiViewBase::afterSwitchFrom() and KexiViewBase::beforeSwitchTo()
- //!< means that parent dialog of the view has not yet view defined.
+ //!< means that tqparent dialog of the view has not yet view defined.
DataViewMode = 1,
DesignViewMode = 2,
TextViewMode = 4 //!< Also known as SQL View Mode
};
//! i18n'ed name of view mode \a m
- KEXICORE_EXPORT QString nameForViewMode(int m);
+ KEXICORE_EXPORT TQString nameForViewMode(int m);
//! A set of known connections
KEXICORE_EXPORT KexiDBConnectionSet& connset();
@@ -83,65 +83,65 @@ namespace Kexi
/*! A global setting for minimal readable font.
Note: this is defined because KDE has no such setting yet.
- \a init is a widget that should be passed if no qApp->mainWidget() is available yet. */
- KEXICORE_EXPORT QFont smallFont(QWidget *init = 0);
+ \a init is a widget that should be passed if no tqApp->mainWidget() is available yet. */
+ KEXICORE_EXPORT TQFont smallFont(TQWidget *init = 0);
/*! Helper class for storing object status. */
- class KEXICORE_EXPORT ObjectStatus
+ class KEXICORE_EXPORT ObjecttqStatus
{
public:
- ObjectStatus();
+ ObjecttqStatus();
- ObjectStatus(const QString& message, const QString& description);
+ ObjecttqStatus(const TQString& message, const TQString& description);
- ObjectStatus(KexiDB::Object* dbObject, const QString& message, const QString& description);
+ ObjecttqStatus(KexiDB::Object* dbObject, const TQString& message, const TQString& description);
- ~ObjectStatus();
+ ~ObjecttqStatus();
- const ObjectStatus& status() const;
+ const ObjecttqStatus& status() const;
bool error() const;
- void setStatus(const QString& message, const QString& description);
+ void settqStatus(const TQString& message, const TQString& description);
- //! Note: for safety, \a dbObject needs to be derived from QObject,
+ //! Note: for safety, \a dbObject needs to be derived from TQObject,
//! otherwise it won't be assigned
- void setStatus(KexiDB::Object* dbObject,
- const QString& message = QString::null, const QString& description = QString::null);
+ void settqStatus(KexiDB::Object* dbObject,
+ const TQString& message = TQString(), const TQString& description = TQString());
- void setStatus(KexiDB::ResultInfo* result,
- const QString& message = QString::null, const QString& description = QString::null);
+ void settqStatus(KexiDB::ResultInfo* result,
+ const TQString& message = TQString(), const TQString& description = TQString());
- void setStatus(KexiDB::Object* dbObject, KexiDB::ResultInfo* result,
- const QString& message = QString::null, const QString& description = QString::null);
+ void settqStatus(KexiDB::Object* dbObject, KexiDB::ResultInfo* result,
+ const TQString& message = TQString(), const TQString& description = TQString());
- void clearStatus();
+ void cleartqStatus();
- QString singleStatusString() const;
+ TQString singleStatusString() const;
- void append( const ObjectStatus& otherStatus );
+ void append( const ObjecttqStatus& othertqStatus );
- KexiDB::Object *dbObject() const { return dynamic_cast<KexiDB::Object*>((QObject*)dbObj); }
+ KexiDB::Object *dbObject() const { return dynamic_cast<KexiDB::Object*>((TQObject*)dbObj); }
- //! Helper returning pseudo handler that just updates this ObjectStatus object
+ //! Helper returning pseudo handler that just updates this ObjecttqStatus object
//! by receiving a message
operator KexiDB::MessageHandler*();
- QString message, description;
+ TQString message, description;
protected:
- QGuardedPtr<QObject> dbObj; //! This is in fact KexiDB::Object
+ TQGuardedPtr<TQObject> dbObj; //! This is in fact KexiDB::Object
KexiDB::MessageHandler* msgHandler;
};
- KEXICORE_EXPORT QString msgYouCanImproveData();
+ KEXICORE_EXPORT TQString msgYouCanImproveData();
}//namespace Kexi
//! Displays information that feature "feature_name" is not availabe in the current application version
-KEXICORE_EXPORT void KEXI_UNFINISHED(const QString& feature_name, const QString& extra_text = QString::null);
+KEXICORE_EXPORT void KEXI_UNFINISHED(const TQString& feature_name, const TQString& extra_text = TQString());
//! Like above - for use inside KexiActionProxy subclass - reuses feature name from shared action's text
#define KEXI_UNFINISHED_SHARED_ACTION(action_name) \
- KEXI_UNFINISHED(sharedAction(action_name) ? sharedAction(action_name)->text() : QString::null)
+ KEXI_UNFINISHED(sharedAction(action_name) ? sharedAction(action_name)->text() : TQString())
#endif